DeckItem class

A data object, that represents collapsed and expanded content of the Deck item.

Constructors

DeckItem({Key? key, required Widget child, required Widget childExpanded})

Properties

child → Widget
The widget to display when the item is collapsed
final
childExpanded → Widget
The widget to display when the item is expanded
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited