ProgressUic class

Inheritance

Constructors

ProgressUic({Key? key, Widget? child, Color? color, Color dimColor = Colors.black38, bool dimContent = false, bool inProgress = true, bool looseConstraints = false, double? size, String? text = '', ProgressUicTextLocation textLocation = ProgressUicTextLocation.bottom, TextStyle? textStyle})
const

Properties

child → Widget?
Content to display.
final
color → Color?
A color of progress indicator.
final
dimColor → Color
A color to dim the content with.
final
dimContent → bool
Whether or not to dim the content while progress indicator is shown.
final
hashCode → int
The hash code for this object.
no setterinherited
inProgress → bool
The progress state.
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
looseConstraints → bool
Whether or not the widget size will be as small as possible, assuming the size.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → double?
The size of the progress indicator
final
text → String?
Text to display near the progress indicator
final
textLocation → ProgressUicTextLocation
Where the text is located related to progress indicator
final
textStyle → TextStyle?
A text style.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited