FormFactor class

A model of the screen.

It is used to define all supported screens and matched views.

See also:

Constructors

FormFactor({double crossAxisMinWidth = 0.0, Orientation orientation = Orientation.portrait})
Creates an instance of the FormFactor.
const

Properties

crossAxisMinWidth → double
Minimum size of the screen in cross axis.
final
hashCode → int
The hash code for this object.
no setteroverride
orientation → Orientation
Orientation of the screen.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override