FormFactorOrientationLocks class

Control supported screen orientation.

Allows to lock screen orientation for some platforms, like web for example. So the orientation returned by MediaQuery would be ignored.

Constructors

FormFactorOrientationLocks({bool webPortrait = true, bool webLandscape = false})
Creates an instance of FormFactorOrientationLocks.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webLandscape → bool
Lock landscape orientation on web.
final
webPortrait → bool
Lock portrait orientation on web.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited