ResponsiveLayout class

Displays a child that match current form factor.

Form factors used as keys for children must be a subset of the form factors list defined in FormFactors widget.

For example:

FormFactors(
  formFactors: const <FormFactor>[
    Screens.formFactorA,
    Screens.formFactorALandscape,
    Screens.formFactorB,
    Screens.formFactorC,
    Screens.formFactorD,
    Screens.formFactorE,
  child: ResponsiveLayout(
    children: {
      Screens.formFactorB: WidgetB(),
      Screens.formFactorD: WidgetD(),
    }
  )
)

class Screens {
  static const formFactorA = FormFactor(crossAxisMinWidth: 300);
  static const formFactorALandscape = FormFactor(crossAxisMinWidth: 300, orientation: Orientation.landscape);
  static const formFactorB = FormFactor(crossAxisMinWidth: 400);
  static const formFactorC = FormFactor(crossAxisMinWidth: 500);
  static const formFactorD = FormFactor(crossAxisMinWidth: 600);
  static const formFactorE = FormFactor(crossAxisMinWidth: 700);
}

When matching children for missing form factors, the children matching logic implemented in DefaultResponsiveLayoutDelegate class considers the order of form factors list defined in FormFactors widget .

See also:

Inheritance

Constructors

ResponsiveLayout({Key? key, required Map<FormFactor, Widget> children, ResponsiveLayoutDelegate delegate = const DefaultResponsiveLayoutDelegate()})
Creates an instance of ResponsiveLayout widget.
const

Properties

children → Map<FormFactor, Widget>
A list of possible child widgets matched to form factors.
final
delegate → ResponsiveLayoutDelegate
Provides a logic of matching child widgets to form factors.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<ResponsiveLayout>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited